@@ -33,6 +33,8 @@
 #endif
 #include <libfm/fm-gtk.h>
 
+#include "gtk-compat.h"
+
 static GtkWidget* win = NULL; /* the run dialog */
 #ifndef DISABLE_MENU
 static MenuCache* menu_cache = NULL;
@@ -228,6 +230,9 @@ static gpointer thread_func(ThreadData* data)
     data->files = list;
     /* install an idle handler to free associated data */
     g_idle_add((GSourceFunc)on_thread_finished, data);
+#if GLIB_CHECK_VERSION(2, 32, 0)
+    g_thread_unref(g_thread_self());
+#endif
 
     return NULL;
 }
@@ -245,7 +250,14 @@ static void setup_auto_complete( GtkEntry* entry )
         /* load in another working thread */
         thread_data = g_slice_new0(ThreadData); /* the data will be freed in idle handler later. */
         thread_data->entry = entry;
+#if GLIB_CHECK_VERSION(2, 32, 0)
+        g_thread_new("gtk-run-autocomplete", (GThreadFunc)thread_func, thread_data);
+        /* we don't use loader_thread_id but Glib 2.32 crashes if we unref
+           GThread while it's in creation progress. It is a bug of GLib
+           certainly but as workaround we'll unref it in the thread itself */
+#else
         g_thread_create((GThreadFunc)thread_func, thread_data, FALSE, NULL);
+#endif
     }
 }
 
@@ -258,7 +270,7 @@ static void reload_apps(MenuCache* cache, gpointer user_data)
         g_slist_foreach(app_list, (GFunc)menu_cache_item_unref, NULL);
         g_slist_free(app_list);
     }
-    app_list = (GSList*)menu_cache_list_all_apps(cache);
+    app_list = menu_cache_list_all_apps(cache);
 }
 #endif
 
@@ -409,11 +421,21 @@ void gtk_run()
         g_signal_connect(entry ,"changed", G_CALLBACK(on_entry_changed), img);
 
         /* get all apps */
+#ifndef MENU_CACHE_CHECK_VERSION
+#define MENU_CACHE_CHECK_VERSION(a,b,c) 0
+#endif
+#if MENU_CACHE_CHECK_VERSION(0, 6, 1)
+        menu_cache = menu_cache_lookup_sync(g_getenv("XDG_MENU_PREFIX") ? "applications.menu" : "lxde-applications.menu" );
+        if( menu_cache )
+        {
+#else
+        /* SF bug #689: menu_cache_lookup_sync() was fail-prone before 0.6.1 */
         menu_cache = menu_cache_lookup(g_getenv("XDG_MENU_PREFIX") ? "applications.menu" : "lxde-applications.menu" );
         if( menu_cache )
         {
             menu_cache_reload(menu_cache);
-            app_list = (GSList*)menu_cache_list_all_apps(menu_cache);
+#endif
+            app_list = menu_cache_list_all_apps(menu_cache);
             reload_notify_id = menu_cache_add_reload_notify(menu_cache, reload_apps, NULL);
         }
 #endif
