@@ -292,6 +292,8 @@ static void panel_icon_grid_size_request(GtkWidget *widget,
                     w = 0;
                     ig->rows++;
                 }
+                if (w > 0)
+                    w += ig->spacing;
                 w += child_requisition.width;
                 requisition->width = MAX(requisition->width, w);
             }
@@ -304,6 +306,8 @@ static void panel_icon_grid_size_request(GtkWidget *widget,
         requisition->height = 0;
     else
         requisition->height = (ig->child_height + ig->spacing) * ig->rows - ig->spacing + 2 * border;
+    if (requisition->width > 0)
+        requisition->width += 2 * border;
 
     if (ig->rows != old_rows || ig->columns != old_columns)
         gtk_widget_queue_resize(widget);
@@ -723,11 +727,11 @@ static GType panel_icon_grid_child_type(GtkContainer *container)
     return GTK_TYPE_WIDGET;
 }
 
-static void panel_icon_grid_class_init(PanelIconGridClass *class)
+static void panel_icon_grid_class_init(PanelIconGridClass *klass)
 {
-    GObjectClass *object_class = G_OBJECT_CLASS(class);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(class);
-    GtkContainerClass *container_class = GTK_CONTAINER_CLASS(class);
+    GObjectClass *object_class = G_OBJECT_CLASS(klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
+    GtkContainerClass *container_class = GTK_CONTAINER_CLASS(klass);
 
     object_class->set_property = panel_icon_grid_set_property;
     object_class->get_property = panel_icon_grid_get_property;
